==> qtjambi-qt3drender-debuginfo-windows-x64-5.15.18.jar: sources/QtJambi3DRender/QAbstractTexture_shell.h <==
#ifndef QABSTRACTTEXTURE_SHELL_H
#define QABSTRACTTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DRender/qabstracttexture.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodecommand.h>
#include <Qt3DCore/qnodecreatedchange.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DCore/qscenechange.h>
#include <Qt3DRender/qabstracttextureimage.h>
#include <Qt3DRender/qtexturedataupdate.h>
#include <Qt3DRender/qtexturegenerator.h>
#include <Qt3DRender/qtexturewrapmode.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractTexture_shell : public Qt3DRender::QAbstractTexture, public QtJambiShellInterface
{
public:
    QAbstractTexture_shell(Qt3DCore::QNode* parent0 = nullptr);
    QAbstractTexture_shell(qint32 target0, Qt3DCore::QNode* parent1 = nullptr);
    ~QAbstractTexture_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sceneChangeEvent(const QSharedPointer<Qt3DCore::QSceneChange>& change0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTexture_access : public Qt3DRender::QAbstractTexture
{
    void __qt_setHandle_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject handle0);
    void __qt_setHandleType_Qt3DRender_QAbstractTexture_HandleType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    void __qt_setStatus_Qt3DRender_QAbstractTexture_Status(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint status0);
    void __qt_sceneChangeEvent_cref_QSharedPointer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject change0);
};

#endif // QABSTRACTTEXTURE_SHELL_H

==> qtjambi-qt3drender-debuginfo-windows-x64-6.6.0.jar: sources/QtJambi3DRender/QAbstractTexture_shell.h <==
#ifndef QABSTRACTTEXTURE_SHELL_H
#define QABSTRACTTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qabstracttexture.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qabstracttextureimage.h>
#include <Qt3DRender/qtexturedataupdate.h>
#include <Qt3DRender/qtexturewrapmode.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QAbstractTexture_shell : public Qt3DRender::QAbstractTexture, public QtJambiShellInterface
{
public:
    QAbstractTexture_shell(Qt3DCore::QNode* parent0 = nullptr);
    QAbstractTexture_shell(qint32 target0, Qt3DCore::QNode* parent1 = nullptr);
    ~QAbstractTexture_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTexture_access : public Qt3DRender::QAbstractTexture
{
    void __qt_setHandle_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject handle0);
    void __qt_setHandleType_Qt3DRender_QAbstractTexture_HandleType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    void __qt_setStatus_Qt3DRender_QAbstractTexture_Status(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint status0);
};

#endif // QABSTRACTTEXTURE_SHELL_H
